@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.34 2003/01/20 15:35:37 bazsi Exp $ */
+ * $Id: io.c,v 1.35 2003/01/31 09:27:02 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -361,7 +361,7 @@ static int do_read(struct abstract_read **r, UINT32 length, UINT8 *buffer)
     }
 }
 
-static int do_recv(struct abstract_read **r, UINT32 length, UINT8 *buffer, abstract_addr *addr, int *addrlen)
+static int do_recv(struct abstract_read **r, UINT32 length, UINT8 *buffer, abstract_addr *addr, socklen_t *addrlen)
 {
 	CAST(fd_read, closure, *r);
 
